@@ -11,10 +11,6 @@ def groupSections(topTrends, script, pageStart):
 
     newScript = categorizeSections(topTrends, script, pageStart)
     newScript = combineCategories(newScript, pageStart)
-
-    file1 = open('./test.json', 'w+')
-    json.dump(newScript, file1, indent=4, ensure_ascii=False)
-
     newScript = divideParentheticals(newScript)
     return newScript
 
